ProceduralAudio

Struct ProceduralAudio 

pub struct ProceduralAudio { /* private fields */ }
Procedural audio generator for Pong.

Generates audio events based on game state changes. Events are returned as JSON to be executed by JavaScript’s Web Audio API.

Example

use jugar_web::audio::ProceduralAudio;

let mut audio = ProceduralAudio::new();
audio.set_enabled(true);

// Trigger a paddle hit sound (hit_y, paddle_y, paddle_height)
audio.on_paddle_hit(300.0, 250.0, 100.0);

// Get events to send to JavaScript
let events = audio.take_events();
assert!(!events.is_empty());

Implementations

Source

impl ProceduralAudio

pub fn new() -> Self

Creates a new audio generator.

pub fn set_volume(&mut self, volume: f32)

Sets the master volume (0.0-1.0).

pub const fn volume(&self) -> f32

Returns the current master volume.

pub fn set_enabled(&mut self, enabled: bool)

Enables or disables audio.

pub const fn is_enabled(&self) -> bool

Returns whether audio is enabled.

pub fn on_paddle_hit(&mut self, hit_y: f32, paddle_y: f32, paddle_height: f32)

Generates a paddle hit sound.

Arguments
  • hit_y - Y position where ball hit the paddle
  • paddle_y - Center Y position of the paddle
  • paddle_height - Height of the paddle
pub fn on_wall_bounce(&mut self)

Generates a wall bounce sound with optional velocity-based pitch variation.

pub fn on_wall_bounce_with_velocity(&mut self, ball_speed: f32, base_speed: f32)

Generates a wall bounce sound with velocity-based pitch.

Arguments
  • ball_speed - Current ball speed (magnitude of velocity)
  • base_speed - Reference speed for normal pitch
pub fn on_goal(&mut self, player_scored: bool)

Generates a goal sound.

Arguments
  • player_scored - True if the player (left paddle) scored
pub fn on_game_start(&mut self)

Generates a game start sound.

pub fn on_rally_milestone(&mut self, rally_count: u32)

Generates a rally milestone sound.

Should be called when rally count reaches a milestone (5, 10, 15, etc.).

Arguments
  • rally_count - Current rally count at the milestone
pub fn on_sound_toggle(&mut self, enabled: bool)

Generates a sound toggle confirmation sound.

Plays a brief confirmation when sound is enabled. This provides immediate feedback that audio is working.

pub fn take_events(&mut self) -> Vec<AudioEvent>

Takes all pending audio events (clears the internal buffer).

Returns

Vector of audio events to be played by JavaScript.

pub fn peek_events(&self) -> &[AudioEvent]

Returns pending events without clearing (for inspection).

pub fn clear_events(&mut self)

Clears all pending events.

pub fn event_count(&self) -> usize

Returns the number of pending events.