Canvas2DCommand

Enum Canvas2DCommand 

pub enum Canvas2DCommand {
Show 15 variants Clear { color: Color, }, FillRect { x: f32, y: f32, width: f32, height: f32, color: Color, }, StrokeRect { x: f32, y: f32, width: f32, height: f32, color: Color, line_width: f32, }, FillCircle { x: f32, y: f32, radius: f32, color: Color, }, StrokeCircle { x: f32, y: f32, radius: f32, color: Color, line_width: f32, }, Line { x1: f32, y1: f32, x2: f32, y2: f32, color: Color, line_width: f32, }, FillText { text: String, x: f32, y: f32, font: String, color: Color, align: TextAlign, baseline: TextBaseline, }, DrawImage { texture_id: u32, x: f32, y: f32, width: f32, height: f32, }, DrawImageSlice { texture_id: u32, src_x: f32, src_y: f32, src_width: f32, src_height: f32, dst_x: f32, dst_y: f32, dst_width: f32, dst_height: f32, }, Save, Restore, Translate { x: f32, y: f32, }, Rotate { angle: f32, }, Scale { x: f32, y: f32, }, SetAlpha { alpha: f32, },
}
Canvas2D render commands that are serialized to JSON.

These commands are designed to be minimal and directly map to Canvas2D API calls. The JavaScript renderer simply iterates over commands and executes them.

Variants



Clear

Clear the entire canvas with a color.

Fields

color: Color

Fill color for clearing



FillRect

Fill a rectangle.

Fields

x: f32

X position

y: f32

Y position

width: f32

Width

height: f32

Height

color: Color

Fill color



StrokeRect

Stroke a rectangle outline.

Fields

x: f32

X position

y: f32

Y position

width: f32

Width

height: f32

Height

color: Color

Stroke color

line_width: f32

Line width



FillCircle

Fill a circle.

Fields

x: f32

Center X

y: f32

Center Y

radius: f32

Radius

color: Color

Fill color



StrokeCircle

Stroke a circle outline.

Fields

x: f32

Center X

y: f32

Center Y

radius: f32

Radius

color: Color

Stroke color

line_width: f32

Line width



Line

Draw a line.

Fields

x1: f32

Start X

y1: f32

Start Y

x2: f32

End X

y2: f32

End Y

color: Color

Line color

line_width: f32

Line width



FillText

Draw text.

Fields

text: String

Text content

x: f32

X position

y: f32

Y position

font: String

CSS font string (e.g., “48px monospace”)

color: Color

Text color

align: TextAlign

Text alignment

baseline: TextBaseline

Text baseline



DrawImage

Draw an image/sprite from a loaded texture.

Fields

texture_id: u32

Texture ID (index into loaded textures array)

x: f32

Destination X

y: f32

Destination Y

width: f32

Destination width

height: f32

Destination height



DrawImageSlice

Draw a portion of an image (sprite sheet).

Fields

texture_id: u32

Texture ID

src_x: f32

Source X in texture

src_y: f32

Source Y in texture

src_width: f32

Source width

src_height: f32

Source height

dst_x: f32

Destination X

dst_y: f32

Destination Y

dst_width: f32

Destination width

dst_height: f32

Destination height



Save

Save the current canvas state.



Restore

Restore the previously saved canvas state.



Translate

Translate the canvas origin.

Fields

x: f32

X translation

y: f32

Y translation



Rotate

Rotate the canvas.

Fields

angle: f32

Rotation angle in radians



Scale

Scale the canvas.

Fields

x: f32

X scale factor

y: f32

Y scale factor



SetAlpha

Set global alpha (opacity).

Fields

alpha: f32

Alpha value (0.0 to 1.0)