pub struct FrameTimer { /* private fields */ }Expand description
Frame time tracker for computing frame statistics.
Implementations
Sourceimpl FrameTimer
impl FrameTimer
Sourcepub const fn with_fixed_dt(fixed_dt: f64) -> Self
pub const fn with_fixed_dt(fixed_dt: f64) -> Self
Creates a frame timer with custom fixed timestep.
Sourcepub fn set_max_dt(&mut self, max_dt: f64)
pub fn set_max_dt(&mut self, max_dt: f64)
Sets the maximum allowed delta time.
Sourcepub fn set_fixed_dt(&mut self, fixed_dt: f64)
pub fn set_fixed_dt(&mut self, fixed_dt: f64)
Sets the fixed timestep interval.
Sourcepub fn consume_fixed_step(&mut self) -> Option<f64>
pub fn consume_fixed_step(&mut self) -> Option<f64>
Sourcepub fn interpolation_alpha(&self) -> f64
pub fn interpolation_alpha(&self) -> f64
Returns the interpolation alpha for rendering between physics steps.
This value (0.0 to 1.0) indicates how far between the last and next physics step we are, useful for interpolating visual positions.
Sourcepub const fn total_time(&self) -> f64
pub const fn total_time(&self) -> f64
Returns the total elapsed time since the timer was created.
Sourcepub const fn frame_count(&self) -> u64
pub const fn frame_count(&self) -> u64
Returns the total number of frames processed.
Sourcepub fn average_fps(&self) -> f64
pub fn average_fps(&self) -> f64
Returns the average frames per second.
Sourcepub const fn accumulator(&self) -> f64
pub const fn accumulator(&self) -> f64
Returns the remaining accumulator time.